# History

## 0.1.3 (2023-07-26)
- Fix mislabeling of 2 AGPL v3 as GPL v3

## 0.0.1 (2023-01-10)

- Add license scanner
- Find all licenses in your env

## 0.0.0 (1970-01-01)

- Copied basic package a start of license_scanner
